@@ -274,21 +274,25 @@ class Frame(Component):
             else:
                 self.total_rows = math.ceil(len(self.components) / self.max_columns)
 
+            print(f'{self.total_rows=}')
+
             if (
                 self.fill['fill'] == 'both'
                 or self.fill['fill'] == 'x'
             ):
-                if self.max_columns is not None:
-                    for i in range(self.max_columns):
-                        self.tkinter.columnconfigure(i, weight=1)
-                        print(i, self)
-                else:
+                if not self.max_columns:
+                    print('None = 0')
                     self.tkinter.columnconfigure(0, weight=1)
+                else:
+                    for i in range(self.max_columns + 1):
+                        print(f'range {i=}')
+                        self.tkinter.columnconfigure(i, weight=1)
             if (
                 self.fill['fill'] == 'both'
                 or self.fill['fill'] == 'y'
             ):
-                for i in range(self.total_rows):
+                for i in range(self.total_rows + 1):
+                    print(f'rows {i=}')
                     self.tkinter.rowconfigure(i, weight=1)
 
             for component in self.components:
